@@ -35,7 +35,7 @@ has 'last_response' => (
     isa => 'Maybe[WebService::Solr::Response]',
 );
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 sub BUILDARGS {
     my ( $self, $url, $options ) = @_;
@@ -160,7 +160,8 @@ sub generic_solr_request {
         WebService::Solr::Response->new(
             $self->agent->post(
                 $self->_gen_url( $path ),
-                $params ) ) );
+                Content_Type => 'application/x-www-form-urlencoded; charset=utf-8',
+                Content => $params ) ) );
 }
 
 sub _gen_url {
@@ -378,7 +379,7 @@ Kirk Beers
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2011 National Adult Literacy Database
+Copyright 2008-2012 National Adult Literacy Database
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
